#ifndef FUNCTIONS_H
#define FUNCTIONS_H
void usage(char *progname);
void generate_ip(char *start, char *end);
void add_ip(char *ip);
int add_ips(char *ip, int mask);
void pingsweep(int numhosts);
void process_alive(int num_hosts);
inline unsigned short ip_cksum(u_short *addr, int len);
void printlist();
void icmp_send();
void udp_send();
void tcp_send();
void check_udp(u_char *data, u_short len);
void check_icmp(u_char *data, u_short len);
void check_tcp(u_char *data, u_short len);
void dolisten(pcap_t *pd);
void read_processor(u_char *disp, struct pcap_pkthdr *h, u_char *data);
int createsock(char *type);
#endif
